@@ -26,7 +26,7 @@ class LayerTest(s_t_utils.SynTest):
 
     def checkLayrvers(self, core):
         for layr in core.layers.values():
-            self.eq(layr.layrvers, 7)
+            self.eq(layr.layrvers, 8)
 
     async def test_layer_verify(self):
 
@@ -874,10 +874,11 @@ class LayerTest(s_t_utils.SynTest):
     async def test_layer_stortype_hugenum(self):
         stor = s_layer.StorTypeHugeNum(self, None)
 
-        vals = [-99999.9, -0.0000000001, -42.1, -0.0, 0.0, 0.000001, 42.1, 99999.9, 2**63 + 1.1]
+        vals = ['-99999.9', '-0.00000000000000000001', '-42.1', '0', '0.000001', '42.1',
+                '99999.9', '730750818665451459101842', '-730750818665451459101842']
 
         for valu, indx in ((v, stor.indx(v)) for v in vals):
-            self.eqish(valu, stor.decodeIndx(indx[0]), places=3)
+            self.eq(valu, stor.decodeIndx(indx[0]))
 
     async def test_layer_stortype_ival(self):
         stor = s_layer.StorTypeIval(self)
@@ -1583,6 +1584,77 @@ class LayerTest(s_t_utils.SynTest):
 
             self.checkLayrvers(core)
 
+    async def test_layer_v8(self):
+        async with self.getRegrCore('2.85.1-hugenum-indx') as core:
+
+            nodes = await core.nodes('inet:fqdn:_huge=1.23')
+            self.len(1, nodes)
+
+            nodes = await core.nodes('inet:fqdn:_huge:array=(1.23, 2.34)')
+            self.len(1, nodes)
+
+            nodes = await core.nodes('inet:fqdn:_huge:array*[=1.23]')
+            self.len(2, nodes)
+
+            nodes = await core.nodes('inet:fqdn:_huge:array*[=2.34]')
+            self.len(2, nodes)
+
+            nodes = await core.nodes('inet:fqdn._univhuge=2.34')
+            self.len(1, nodes)
+
+            nodes = await core.nodes('._univhuge=2.34')
+            self.len(1, nodes)
+
+            nodes = await core.nodes('inet:fqdn._hugearray=(3.45, 4.56)')
+            self.len(1, nodes)
+
+            nodes = await core.nodes('inet:fqdn._hugearray*[=3.45]')
+            self.len(2, nodes)
+
+            nodes = await core.nodes('inet:fqdn._hugearray*[=4.56]')
+            self.len(2, nodes)
+
+            nodes = await core.nodes('._hugearray=(3.45, 4.56)')
+            self.len(1, nodes)
+
+            nodes = await core.nodes('._hugearray*[=3.45]')
+            self.len(2, nodes)
+
+            nodes = await core.nodes('._hugearray*[=4.56]')
+            self.len(2, nodes)
+
+            nodes = await core.nodes('inet:fqdn#bar:cool:huge=1.23')
+            self.len(1, nodes)
+
+            nodes = await core.nodes('#bar:cool:huge=1.23')
+            self.len(1, nodes)
+
+            nodes = await core.nodes('inet:fqdn:_huge:array = (1.23, 10E-21)')
+            self.len(1, nodes)
+            self.eq(nodes[0].props['_huge:array'], ('1.23', '0.00000000000000000001'))
+
+            nodes = await core.nodes('inet:fqdn._hugearray = (3.45, 10E-21)')
+            self.len(1, nodes)
+            self.eq(nodes[0].props['._hugearray'], ('3.45', '0.00000000000000000001'))
+
+            nodes = await core.nodes('inet:fqdn:_huge:array*[=10E-21]')
+            self.len(1, nodes)
+            self.eq(nodes[0].props['_huge:array'], ('1.23', '0.00000000000000000001'))
+
+            nodes = await core.nodes('inet:fqdn._hugearray*[=10E-21]')
+            self.len(1, nodes)
+            self.eq(nodes[0].props['._hugearray'], ('3.45', '0.00000000000000000001'))
+
+            nodes = await core.nodes('inet:fqdn:_huge=0.00000000000000000001')
+            self.len(1, nodes)
+            node = nodes[0]
+            self.eq(node.props.get('_huge'), '0.00000000000000000001')
+            self.eq(node.props.get('._univhuge'), '0.00000000000000000001')
+            self.eq(node.props.get('._hugearray'), ('3.45', '0.00000000000000000001'))
+            self.eq(node.props.get('._hugearray'), ('3.45', '0.00000000000000000001'))
+
+            self.checkLayrvers(core)
+
     async def test_layer_logedits_default(self):
         async with self.getTestCore() as core:
             self.true(core.getLayer().logedits)
